==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetTopicEventSubscriptionFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventSubscriptionName Name of the event subscription.
 * @property resourceGroupName The name of the resource group within the user's subscription.
 * @property topicName Name of the domain topic.
 */
public data class GetTopicEventSubscriptionFullUrlPlainArgs(
    public val eventSubscriptionName: String,
    public val resourceGroupName: String,
    public val topicName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs.builder()
            .eventSubscriptionName(eventSubscriptionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTopicEventSubscriptionFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetTopicEventSubscriptionFullUrlPlainArgsBuilder internal constructor() {
    private var eventSubscriptionName: String? = null

    private var resourceGroupName: String? = null

    private var topicName: String? = null

    /**
     * @param value Name of the event subscription.
     */
    @JvmName("qpsfeprqvliogcff")
    public suspend fun eventSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.eventSubscriptionName = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription.
     */
    @JvmName("bfvcqecqamusrmhd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the domain topic.
     */
    @JvmName("rblfljefwujtrsqp")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): GetTopicEventSubscriptionFullUrlPlainArgs =
        GetTopicEventSubscriptionFullUrlPlainArgs(
            eventSubscriptionName = eventSubscriptionName ?: throw
                PulumiNullFieldException("eventSubscriptionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            topicName = topicName ?: throw PulumiNullFieldException("topicName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetTopicEventSubscriptionFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventSubscriptionName Name of the event subscription.
 * @property resourceGroupName The name of the resource group within the user's subscription.
 * @property topicName Name of the domain topic.
 */
public data class GetTopicEventSubscriptionFullUrlPlainArgs(
    public val eventSubscriptionName: String,
    public val resourceGroupName: String,
    public val topicName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetTopicEventSubscriptionFullUrlPlainArgs.builder()
            .eventSubscriptionName(eventSubscriptionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTopicEventSubscriptionFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetTopicEventSubscriptionFullUrlPlainArgsBuilder internal constructor() {
    private var eventSubscriptionName: String? = null

    private var resourceGroupName: String? = null

    private var topicName: String? = null

    /**
     * @param value Name of the event subscription.
     */
    @JvmName("dmruaejepswcoqdl")
    public suspend fun eventSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.eventSubscriptionName = mapped
    }

    /**
     * @param value The name of the resource group within the user's subscription.
     */
    @JvmName("ihvpgyxgkdkvljdr")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the domain topic.
     */
    @JvmName("djkbcqrpvypudgoh")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): GetTopicEventSubscriptionFullUrlPlainArgs =
        GetTopicEventSubscriptionFullUrlPlainArgs(
            eventSubscriptionName = eventSubscriptionName ?: throw
                PulumiNullFieldException("eventSubscriptionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            topicName = topicName ?: throw PulumiNullFieldException("topicName"),
        )
}
